<?php


class Tribe__Tickets_Plus__Commerce__WooCommerce__Orders__Cancelled {

	/**
	 * @var Tribe__Tickets_Plus__Commerce__WooCommerce__Orders__Cancelled[]
	 */
	protected static $instances;

	/**
	 * @var int
	 */
	protected $ticket_id;

	/**
	 * @var int
	 */
	protected $count_cache = false;

	/**
	 * @param $ticket_id
	 *
	 * @return Tribe__Tickets_Plus__Commerce__WooCommerce__Orders__Cancelled|WP_Error
	 */
	public static function for_ticket( $ticket_id ) {

		if ( empty( self::$instances[ $ticket_id ] ) ) {
			try {
				self::$instances[ $ticket_id ] = new self( $ticket_id );
			} catch ( InvalidArgumentException $e ) {
				return new WP_Error( 'invalid-ticket-id', $e->getMessage() );
			}
		}

		return self::$instances[ $ticket_id ];
	}

	/**
	 * Tribe__Tickets_Plus__Commerce__WooCommerce__Orders__Cancelled constructor.
	 *
	 * Reccomended way to instance the object is using the `for_ticket` factory method.
	 *
	 * @param      $ticket_id
	 */
	public function __construct( $ticket_id ) {
		if ( ! is_numeric( $ticket_id ) ) {
			throw new InvalidArgumentException(
				esc_html(
					sprintf(
						__(
							'%s post ID must be an int or a numeric string.',
							'event-tickets-plus'
						),
						tribe_get_ticket_label_singular( 'woo_orders_cancelled_exception' )
					)
				)
			);
		}

		$ticket_post = get_post( $ticket_id );
		if ( empty( $ticket_post ) ) {
			throw new InvalidArgumentException(
				esc_html(
					sprintf(
						__(
							'%1$s with ID %2$s does not exist.',
							'event-tickets-plus'
						),
						tribe_get_ticket_label_singular( 'woo_orders_cancelled_exception' ),
						esc_html( $ticket_id )
					)
				)
			);
		}

		$this->ticket_id = $ticket_id;
	}

	public function get_count() {
		if ( false === $this->count_cache ) {
			$this->count_cache = $this->real_get_count();
		}

		return $this->count_cache;
	}

	protected function real_get_count() {
		$args = [
			'status'     => 'cancelled', // Fetch only cancelled orders.
			'limit'      => -1, // Fetch all matching orders.
			'meta_query' => [
				[
					'key'     => '_product_id',
					'value'   => $this->ticket_id,
					'compare' => '=',
				],
			],
		];

		$cancelled_orders        = wc_get_orders( $args );
		$cancelled_tickets_count = 0;

		foreach ( $cancelled_orders as $order ) {
			foreach ( $order->get_items() as $item ) {
				if ( $item->get_product_id() == $this->ticket_id ) {
					$cancelled_tickets_count += $item->get_quantity();
				}
			}
		}

		return $cancelled_tickets_count;
	}

}
